﻿* Encoding: UTF-8.

comment before doing any analyses, run descriptives. make sure your actor and partner variables have the same means, SDs, but are not perfectly correlated. 

DATASET ACTIVATE DataSet1.
DESCRIPTIVES VARIABLES=overall_tutoring_1_00 overall_tutoring_2_00 ladder_now_1_00 ladder_now_2_00
  /STATISTICS=MEAN STDDEV MIN MAX.

CORRELATIONS
  /VARIABLES=ladder_now_1_00 ladder_now_2_00 overall_tutoring_1_00 overall_tutoring_2_00
  /PRINT=TWOTAIL NOSIG
  /MISSING=PAIRWISE.

comment next make sure to center all of your continuous predictor variables. 

compute ladder_now_1_00C = ladder_now_1_00-6.67.
execute. 

compute ladder_now_2_00C = ladder_now_2_00-6.67.
execute. 


comment model with only actor ladder (ladder_now_1_00C) and role. Note that role is a dichotomous variable but it is "effects coded" (1, -1) and so it can go after the 
WITH statement in SPSS. 
comment note that this model is run using "CSR" which treats the dyads as indistinguishable (it estimates one pooled error variance). 

MIXED
overall_tutoring_1_00  WITH ladder_now_1_00C role
  /FIXED = ladder_now_1_00C role ladder_now_1_00C*role
  /PRINT = SOLUTION TESTCOV
  /REPEATED partnum | SUBJECT(dyad) COVTYPE(CSR) .

comment here is the same model using CSH (separate error variances for the two partners). This is the "actor only" model in excel. 

MIXED
overall_tutoring_1_00  WITH ladder_now_1_00C role 
  /FIXED = ladder_now_1_00C role ladder_now_1_00C*role
  /PRINT = SOLUTION TESTCOV
  /REPEATED partnum | SUBJECT(dyad) COVTYPE(CSH) .

COMMENT WHICH MODEL FITS THE DATA BETTER? LOOK AT THE "-2 RESTRICTED LOG LIKELIHOOD" ESTIMATES AT THE TOP OF THE OUTPUT FOR EACH. 

indistinguishable model = 287.752
distinguishable model = 268.881

what is the difference between these two values? 
18.871. Treat this like a chi square difference test with 1 degree of freedom (because we changed parameter in comparing these models). The critical chi square with 1 df
is 3.841. So treating them as indistinguishable worsens the fit of the model. 

comment expanding the model to include partner ladder. 

MIXED
overall_tutoring_1_00  WITH ladder_now_1_00C ladder_now_2_00C role
  /FIXED = ladder_now_1_00C role ladder_now_1_00C*role
  ladder_now_2_00C   ladder_now_2_00C*role
  /PRINT = SOLUTION TESTCOV
  /REPEATED partnum | SUBJECT(dyad) COVTYPE(CSH) .

comment breaking the interaction down by role. to do so, we need to first recode role so that the reference group is zero. 

RECODE role (1=0) (-1=1) INTO role_tutor.
EXECUTE.
RECODE role (1=1) (-1=0) INTO role_student.
EXECUTE.

comment the main effects of actor and partner ladder for the tutors. 
MIXED
overall_tutoring_1_00  WITH ladder_now_1_00C ladder_now_2_00C role_tutor
  /FIXED = ladder_now_1_00C role_tutor ladder_now_1_00C*role_tutor
  ladder_now_2_00C   ladder_now_2_00C*role_tutor
  /PRINT = SOLUTION TESTCOV
  /REPEATED partnum | SUBJECT(dyad) COVTYPE(CSH) .

comment the main effects of actor and partner ladder for the students. 
MIXED
overall_tutoring_1_00  WITH ladder_now_1_00C ladder_now_2_00C role_student
  /FIXED = ladder_now_1_00C role_student ladder_now_1_00C*role_student
  ladder_now_2_00C   ladder_now_2_00C*role_student
  /PRINT = SOLUTION TESTCOV
  /REPEATED partnum | SUBJECT(dyad) COVTYPE(CSH) .
